### Name: pvcovHC
### Title: Robust covariance matrix estimators
### Aliases: pvcovHC pvcovHC.panelmodel pvcovHC.pgmm
### Keywords: regression

### ** Examples

library(lmtest)
library(car)
data("Produc",package="Ecdat")
zz <- plm(log(gsp)~log(pcap)+log(pc)+log(emp)+unemp,data=Produc,model="random")
## standard coefficient significance test
coeftest(zz)
## robust significance test
coeftest(zz, vcov=pvcovHC)
## idem with parameters, pass vcov as a function argument
coeftest(zz, vcov=function(x) pvcovHC(x, method="arellano", type="HC1"))
## idem with parameters, pass vcov as a matrix argument
coeftest(zz, vcov=pvcovHC(zz, method="arellano", type="HC1"))
## joint restriction test
waldtest(zz, update(zz, .~.-log(emp)-unemp), vcov=pvcovHC)
## test of hyp.: 2*log(pc)=log(emp)
linear.hypothesis(zz, "2*log(pc)=log(emp)", vcov=pvcovHC)

## Robust inference for GMM models
data("EmplUK",package="plm")
ar <- pgmm(dynformula(log(emp)~log(wage)+log(capital)+log(output),list(2,1,2,2)),EmplUK,
           effect="twoways",model="twosteps",
           gmm.inst=~log(emp),lag.gmm=list(c(2,99)))
rv <- pvcovHC(ar)
mtest(ar,order=2,vcov=rv)




